<h1 align = "center">:rocket: FFM :facepunch:</h1>

---

## [FFM][1]
- [PyFM][2]
- [libffm][3]
- [Xlearn][4]










---
[1]: https://tech.meituan.com/deep-understanding-of-ffm-principles-and-practices.html#mjx-eqn-eqpoly
[2]: https://github.com/coreylynch/pyFM
[3]: https://github.com/alexeygrigorev/libffm-python
[4]: https://github.com/aksnzhy/xlearn
